@@ -7,3 +7,6 @@ from ._io import references
 from . import binary_classification
 from . import multiclass_classification
 from . import regression
+from . import clustering
+
+from ._version import *
