@@ -2,10 +2,11 @@
 This module brings together all binary classification data loaders
 """
 
-import pandas as pd
+import json
+import io
+import pkgutil
 
-from ._summary_part0 import summary_part0
-from ._summary_part1 import summary_part1
+import pandas as pd
 
 from ._binary_classification_part0 import (load_abalone_17_vs_7_8_9_10,
 load_abalone_19_vs_10_11_12_13,
@@ -127,13 +128,14 @@ load_crx,
 load_lymphography,
 load_wdbc,
 load_ionosphere,
-load_spectfheart,
-load_ada,
-load_hiva
+load_ada
+#load_hiva
 )
 
+summary = json.loads(pkgutil.get_data('common_datasets', 'data/summary_binary_classification.json').decode('utf-8'))
+
 __all__= ['load_ada',
-            'load_hiva',
+            #'load_hiva',
             'load_abalone_17_vs_7_8_9_10',
             'load_abalone_19_vs_10_11_12_13',
             'load_abalone_20_vs_8_9_10',
@@ -252,13 +254,12 @@ __all__= ['load_ada',
             'load_lymphography',
             'load_wdbc',
             'load_ionosphere',
-            'load_spectfheart',
             'get_data_loaders',
             'get_filtered_data_loaders',
-            'summary_pdf']
+            'summary_pdf',
+            'get_summary_pdf']
 
-
-summary_pdf = pd.DataFrame.from_dict(summary_part0 + summary_part1)
+summary_pdf = pd.DataFrame.from_dict(summary)
 
 def get_filtered_data_loaders(*,
                               n_col_bounds=(1, 5000),
@@ -351,11 +352,24 @@ def get_data_loaders(subset='all',
     elif subset == 'tiny':
         n_bounds = (n_bounds[0], 120)
 
-    return get_filtered_data_loaders(n_col_bounds= n_col_bounds,
-                                    n_col_orig_bounds= n_col_orig_bounds,
-                                    n_bounds= n_bounds,
-                                    n_minority_bounds= n_minority_bounds,
-                                    imbalance_ratio_bounds= imbalance_ratio_bounds,
+    return get_filtered_data_loaders(n_col_bounds=n_col_bounds,
+                                    n_col_orig_bounds=n_col_orig_bounds,
+                                    n_bounds=n_bounds,
+                                    n_minority_bounds=n_minority_bounds,
+                                    imbalance_ratio_bounds=imbalance_ratio_bounds,
                                     n_smallest=n_smallest,
                                     sorting=sorting,
                                     n_from_phenotypes=n_from_phenotypes)
+
+def get_summary_pdf():
+    """
+    Returns the summary pandas dataframe with loader function references
+
+    Returns:
+        pd.DataFrame: the summary pandas dataframe
+    """
+    descriptors = summary_pdf
+
+    descriptors['data_loader_function'] = descriptors['data_loader'].apply(lambda x: globals()[x])
+
+    return descriptors
