@@ -68,9 +68,9 @@ __all__= ['load_kddcup_buffer_overflow_vs_back',
             'load_lymphography',
             'load_wdbc',
             'load_ionosphere',
-            'load_spectfheart',
-            'load_ada',
-            'load_hiva']
+            'load_ada'
+#            'load_hiva'
+             ]
 
 def load_kddcup_buffer_overflow_vs_back():
     """
@@ -649,8 +649,7 @@ def load_monk_2():
     path = 'data/classification/monk-2/monk-2.dat'
     return load_arff_template_binary(path=path,
                                         name='monk-2',
-                                        target_label='Class',
-                                        revert_target=True)
+                                        target_label='Class')
 
 def load_wdbc():
     """
@@ -674,21 +673,20 @@ def load_ionosphere():
     path = 'data/classification/ionosphere/ionosphere.dat'
     return load_arff_template_binary(path=path,
                                         name="ionosphere",
-                                        target_label='Class',
-                                        revert_target=True)
+                                        target_label='Class')
 
-def load_spectfheart():
-    """
-    Load the spectfheart dataset
-
-    Returns:
-        dict: the dataset in sklearn.datasets representation
-    """
-    path = 'data/classification/spectfheart/spectfheart.dat'
-    return load_arff_template_binary(path=path,
-                                        name="spectfheart",
-                                        target_label='OVERALL_DIAGNOSIS',
-                                        revert_target=True)
+#def load_spectfheart():
+#    """
+#    Load the spectfheart dataset
+#
+#    Returns:
+#        dict: the dataset in sklearn.datasets representation
+#    """
+#    path = 'data/classification/spectfheart/spectfheart.dat'
+#    return load_arff_template_binary(path=path,
+#                                        name="spectfheart",
+#                                        target_label='OVERALL_DIAGNOSIS',
+#                                        revert_target=True)
 
 def load_bupa():
     """
@@ -700,8 +698,7 @@ def load_bupa():
     path = 'data/classification/bupa/bupa.dat'
     return load_arff_template_binary(path=path,
                                         name="bupa",
-                                        target_label='Selector',
-                                        revert_target=True)
+                                        target_label='Selector')
 
 def load_crx():
     """
@@ -771,26 +768,26 @@ def load_ada():
                         name='ADA',
                         target_label='target_label')
 
-def load_hiva():
-    """
-    Loads the hiva dataset
-
-    Returns:
-        dict: the dataset in sklearn.datasets representation
-    """
-    data = read_csv_data('data/classification/hiva/hiva_train.data', sep=' ', header=None)
-    labels = read_csv_data('data/classification/hiva/hiva_train.labels', header=None)
-
-    # dummy column replaced by labels due to trailing separator characters
-    data[48] = labels
-    data = data.rename({48: 'target_label'}, axis='columns')
-
-    data[data == '?'] = np.nan
-    data = data.astype(float)
-
-    return prepare_csv_data_template(dataset=data,
-                        name='HIVA',
-                        target_label='target_label')
+#def load_hiva():
+#    """
+#    Loads the hiva dataset
+#
+#    Returns:
+#        dict: the dataset in sklearn.datasets representation
+#    """
+#    data = read_csv_data('data/classification/hiva/hiva_train.data', sep=' ', header=None)
+#    labels = read_csv_data('data/classification/hiva/hiva_train.labels', header=None)
+#
+#    # dummy column replaced by labels due to trailing separator characters
+#    data[48] = labels
+#    data = data.rename({48: 'target_label'}, axis='columns')
+#
+#    data[data == '?'] = np.nan
+#    data = data.astype(float)
+#
+#    return prepare_csv_data_template(dataset=data,
+#                        name='HIVA',
+#                        target_label='target_label')
 
 #def load_glass():
 #    """
@@ -833,8 +830,7 @@ def load_hypothyroid():
 
     return prepare_csv_data_template(dataset=dataset,
                         name='hypothyroid',
-                        target_label='target',
-                        revert_target=True)
+                        target_label='target')
 
 def load_sylva():
     """
@@ -869,8 +865,7 @@ def load_spectf():
 
     return prepare_csv_data_template(dataset=dataset,
                         name='SPECTF',
-                        target_label='target',
-                        revert_target=True)
+                        target_label='target')
 
 def load_hepatitis():
     """
@@ -887,8 +882,7 @@ def load_hepatitis():
 
     return prepare_csv_data_template(dataset=dataset,
                         name='hepatitis',
-                        target_label='target',
-                        revert_target=True)
+                        target_label='target')
 
 #def load_vehicle():
 #    """
