@@ -2,13 +2,17 @@
 This module contains the multiclass data loaders
 """
 
+import json
+import io
+import pkgutil
+
 import pandas as pd
 
 from .._io import (read_csv_data,
                     load_arff_template_multiclass,
                     prepare_csv_data_template)
 
-from ._summary import summary
+summary = json.loads(pkgutil.get_data('common_datasets', 'data/summary_multiclass_classification.json').decode('utf-8'))
 
 summary_pdf = pd.DataFrame.from_dict(summary)
 
@@ -40,7 +44,8 @@ __all__= ['load_glass',
           'load_zoo',
           'get_filtered_data_loaders',
           'get_data_loaders',
-          'summary_pdf']
+          'summary_pdf',
+          'get_summary_pdf']
 
 ########
 # arff #
@@ -477,3 +482,16 @@ def get_data_loaders(subset='all',
                                     n_smallest=n_smallest,
                                     sorting=sorting,
                                     n_from_phenotypes=n_from_phenotypes)
+
+def get_summary_pdf():
+    """
+    Returns the summary pandas dataframe with loader function references
+
+    Returns:
+        pd.DataFrame: the summary pandas dataframe
+    """
+    descriptors = summary_pdf
+
+    descriptors['data_loader_function'] = descriptors['data_loader'].apply(lambda x: globals()[x])
+
+    return descriptors
